@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::Shape::Vector;
-$Math::Shape::Vector::VERSION = '0.11';
+$Math::Shape::Vector::VERSION = '0.12';
 use 5.008;
 use Carp;
 use Math::Shape::Utils;
@@ -187,7 +187,6 @@ sub collides
             && $pr->length <= $d->length
             && 0 <= $pr->dot_product($d)
             ? 1 : 0;
-
     }
     elsif ($other_obj->isa('Math::Shape::Line'))
     {
@@ -217,6 +216,32 @@ sub collides
 }
 
 
+sub distance
+{
+    my ($self, $other_obj) = @_;
+
+    if ($other_obj->isa('Math::Shape::Vector'))
+    {
+        $self->subtract_vector($other_obj)->length;
+    }
+    elsif ($other_obj->isa('Math::Shape::Circle'))
+    {
+        $self->subtract_vector($other_obj->{center})->length
+        - $other_obj->{radius};
+    }
+    elsif ($other_obj->isa('Math::Shape::OrientedRectangle'))
+    {
+        my $circle_hull = $other_obj->circle_hull;
+        $self->subtract_vector($circle_hull->{center})->length
+        - $circle_hull->{radius};
+    }
+    else
+    {
+        croak 'distance() must be called with a Math::Shape::Vector library object';
+    }
+}
+
+
 1;
 
 __END__
@@ -231,7 +256,7 @@ Math::Shape::Vector - A 2d vector library in cartesian space
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -393,13 +418,19 @@ Boolean method that returns 1 if the vector collides with another L<Math::Shape:
     my $circle = Math::Shape::Circle->new(0, 0, 3); # x, y and radius
     $v1->collides($circle); # 0
 
+=head2 distance
+
+Returns the distance from the vector to the nearest point of another shape. Requires an L<Math::Shape::Vector> library object as an argument. Currently only implemented for vector and circle objects. For OrientedRectangle objects, distance uses the distance to the circle hull of the OrientedRectangle (not completely accurate).
+
+    my $distance = $vector->distance($other_vector);
+
 =head1 REPOSITORY
 
 L<https://github.com/sillymoose/Math-Shape-Vector.git>
 
 =head1 THANKS
 
-The source code for this object was inspired by the code in Thomas Schwarzl's 2d collision detection book L<http://www.collisiondetection2d.net>.
+The source code for this class was inspired by the code in Thomas Schwarzl's 2d collision detection book L<http://www.collisiondetection2d.net>.
 
 =head1 AUTHOR
 
